import astropy.units as u
from astropy.coordinates import EarthLocation
from pytz import timezone
from astroplan import Observer

longitude = '-155d28m48.900s'
latitude = '+19d49m42.600s'
elevation = 4163 * u.m
location = EarthLocation.from_geodetic(longitude, latitude, elevation)

subaru = Observer(name='Subaru Telescope',
               location=location,
               timezone=timezone('US/Hawaii'),
               description="Subaru Telescope on Maunakea, Hawaii")

from astropy.coordinates import SkyCoord
from astroplan import FixedTarget

coordinates = SkyCoord('19h50m47.6s', '+08d52m12.0s', frame='icrs')
altair = FixedTarget(name='Altair', coord=coordinates)

coordinates = SkyCoord('18h36m56.5s', '+38d47m06.6s', frame='icrs')
vega = FixedTarget(name='Vega', coord=coordinates)

coordinates = SkyCoord('20h41m25.9s', '+45d16m49.3s', frame='icrs')
deneb = FixedTarget(name='Deneb', coord=coordinates)

from astropy.time import Time

time = Time('2015-06-16 12:00:00')

from astroplan.plots import plot_parallactic
import matplotlib.pyplot as plt

plot_parallactic(altair, subaru, time)
plot_parallactic(vega, subaru, time)
plot_parallactic(deneb, subaru, time)

plt.legend(loc=2)
plt.tight_layout()
plt.show()